﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
//
using System.IO.Ports;
using System.Threading;

/// <summary>
/// Serial ports lib by Jorge P, Heater
/// </summary>
namespace SerialPortsLib
{
    /// <summary>
    /// A class for accessing serial ports through the .NET framework
    /// </summary>
    /// <remarks></remarks>
    public class SerialPortsLib
    {
        /// <summary>Gets an array of serial ports connected when called</summary>
        /// <returns>a string array</returns>
        /// <remarks>This does not open any ports for reading or writing, it simply sees what ports are currently available to communicate with later in code</remarks>
        public string[] getPorts()
        {
            string[] myPorts = SerialPort.GetPortNames();
            return myPorts;
        }
        //Thread t = new ThreadStart(p.Write(text)) ;

        /// <summary>
        /// Tests port access by sending a string to the Serial Port indicated by portName
        /// </summary>
        /// <param name="portName">Full Name of the port to perform the test, varies by OS</param>
        /// <param name="baud">an integer value indicating the baudrate, speed, to communicate at</param>
        /// <param name="parity">System.IO.Ports.Parity vslue</param>
        /// <param name="databits">an integer with a valid datbits value</param>
        /// <param name="stopbits">System.IO.Ports.StopBits selectable enumerator</param>
        /// <param name="handshake">System.IO.Ports.Handshake</param>
        /// <param name="text">a string value with the test you's like to send</param>
        /// <remarks>OMG - Code provided by Heater</remarks>
        public void testSerialPort(string portName, BaudRates baud, Parity parity, int databits, StopBits stopbits, Handshake handshake, string text)
        {
            // create a new port instance called p
            SerialPort p = new SerialPort();
            // set the ports name according to the string passed
            p.PortName = portName;
            //Done: Make the baudrate selectable, Don't hardcode this
            p.BaudRate = Convert.ToInt32(baud);
            //Done: Make parity selectable, Don't hardcode this
            p.Parity = parity;
            //Done: Make the databits selectable, Don't hardcode this
            p.DataBits = databits;
            //Done: Make the stopbits selectable, Don't hardcode this
            p.StopBits = stopbits;
            //Done: Make the handshake selectable, Don't hardcode this
            p.Handshake = handshake;
            //TODO: maybee make ReadTimeout selectable
            p.ReadTimeout = 500;
            //TODO: maybee make WriteTimeout selectable
            p.WriteTimeout = 500;
            p.Open();
            for (int i = 1; i < 1000; i++)
            {
                //Done: make the string passable to this test function
                p.Write(text);
            }
            p.Close();
            p.Dispose(); // this line ensures the port is disposed of but is
                         // generaly handled automaticaly in .NET
        }

#region "Public Enumerations"
        /// <summary>
        /// The currently supported baud rates
        /// </summary>
        public enum BaudRates
        {
            baud_110 = 110,
            baud_300 = 300,
            baud_600 = 600,
            baud_1200 = 1200,
            baud_2400 = 2400,
            baud_4800 = 4800,
            baud_9600 = 9600,
            baud_14400 = 14400,
            baud_19200 = 19200,
            baud_28800 = 28800,
            baud_38400 = 38400,
            baud_56000 = 56000,
            baud_57600 = 57600,
            baud_115200 = 115200,
            baud_128000 = 128000,
            baud_256000 = 256000,
        }

#endregion
    }
}
